@@ -236,6 +236,9 @@ matrixpls <- function(S, model, W.model = NULL, weightFun = weightFun.pls,
   nativeModel <- parseModelToNativeFormat(model)
   
   lvNames <- colnames(nativeModel$inner)
+  if(any(duplicated(lvNames)))
+    stop(paste("Each composite must have a unique name. The names contain duplicates:",
+               lvNames))
   
   if(lvNames != rownames(nativeModel$inner) ||
        lvNames != colnames(nativeModel$reflective) ||
@@ -324,7 +327,7 @@ matrixpls <- function(S, model, W.model = NULL, weightFun = weightFun.pls,
   return(ret)
 }
 
-#'@S3method print matrixpls
+#'@export
 
 print.matrixpls <- function(x, ...){
   
@@ -367,7 +370,7 @@ print.matrixpls <- function(x, ...){
   
 }
 
-#'@S3method summary matrixpls
+#'@export
 
 summary.matrixpls <- function(object, ...){
   
@@ -385,7 +388,7 @@ summary.matrixpls <- function(object, ...){
   return(ret)
 }
 
-#'@S3method print matrixplssummary
+#'@export
 
 print.matrixplssummary <- function(x, ...){
   for(element in x){
